==> cdk_2.7.1.orig.tar.gz: cdk-cdk-2.7.1/tool/smarts/src/test/java/org/openscience/cdk/smarts/DfSubstructureTest.java <==
/*
 * Copyright (C) 2018  The Chemistry Development Kit (CDK) project
 *
 * Contact: cdk-devel@lists.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2.1 of the License, or (at
 * your option) any later version. All we ask is that proper credit is given
 * for our work, which includes - but is not limited to - adding the above
 * copyright notice to the beginning of your source code files, and to any
 * copyright notice that you may distribute with programs based on this work.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 * License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */

package org.openscience.cdk.smarts;

import org.junit.Test;
import org.openscience.cdk.aromaticity.Aromaticity;
import org.openscience.cdk.aromaticity.ElectronDonation;
import org.openscience.cdk.exception.InvalidSmilesException;
import org.openscience.cdk.graph.Cycles;
import org.openscience.cdk.interfaces.IAtomContainer;
import org.openscience.cdk.isomorphism.DfPattern;
import org.openscience.cdk.isomorphism.Pattern;
import org.openscience.cdk.isomorphism.VentoFoggia;
import org.openscience.cdk.silent.SilentChemObjectBuilder;
import org.openscience.cdk.smiles.SmilesParser;
import uk.ac.ebi.beam.Graph;

import java.io.BufferedReader;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;

import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

public class DfSubstructureTest extends SubstructureTest {

    @Override
    Pattern create(IAtomContainer container) {
        return DfPattern.findSubstructure(container);
    }

    @Test
    public void matchRoot() throws Exception {
        IAtomContainer mol  = smi("OC(=O)C(=O)O");
        IAtomContainer qry  = sma("O=*");
        DfPattern      ptrn = DfPattern.findSubstructure(qry);
        assertFalse(ptrn.matchesRoot(mol.getAtom(0)));
        assertTrue(ptrn.matchesRoot(mol.getAtom(2)));
        assertTrue(ptrn.matchesRoot(mol.getAtom(4)));
        assertFalse(ptrn.matchesRoot(mol.getAtom(5)));
    }
}

==> cdk_2.11.orig.tar.gz: cdk-cdk-2.11/tool/smarts/src/test/java/org/openscience/cdk/smarts/DfSubstructureTest.java <==
/*
 * Copyright (C) 2018  The Chemistry Development Kit (CDK) project
 *
 * Contact: cdk-devel@lists.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2.1 of the License, or (at
 * your option) any later version. All we ask is that proper credit is given
 * for our work, which includes - but is not limited to - adding the above
 * copyright notice to the beginning of your source code files, and to any
 * copyright notice that you may distribute with programs based on this work.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 * License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */

package org.openscience.cdk.smarts;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;
import org.openscience.cdk.interfaces.IAtomContainer;
import org.openscience.cdk.isomorphism.DfPattern;
import org.openscience.cdk.isomorphism.Pattern;

class DfSubstructureTest extends SubstructureTest {

    @Override
    Pattern create(IAtomContainer container) {
        return DfPattern.findSubstructure(container);
    }

    @Test
    void matchRoot() throws Exception {
        IAtomContainer mol  = smi("OC(=O)C(=O)O");
        IAtomContainer qry  = sma("O=*");
        DfPattern      ptrn = DfPattern.findSubstructure(qry);
        Assertions.assertFalse(ptrn.matchesRoot(mol.getAtom(0)));
        Assertions.assertTrue(ptrn.matchesRoot(mol.getAtom(2)));
        Assertions.assertTrue(ptrn.matchesRoot(mol.getAtom(4)));
        Assertions.assertFalse(ptrn.matchesRoot(mol.getAtom(5)));
    }
}
